==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkBandwidthSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkBandwidthSpecFluentImpl<A extends NetworkBandwidthSpecFluent<A>> extends BaseFluent<A> implements NetworkBandwidthSpecFluent<A>{
  public NetworkBandwidthSpecFluentImpl() {
  }
  public NetworkBandwidthSpecFluentImpl(NetworkBandwidthSpec instance) {
    this.withBuffer(instance.getBuffer()); 
    this.withDevice(instance.getDevice()); 
    this.withHostname(instance.getHostname()); 
    this.withIpAddress(instance.getIpAddress()); 
    this.withLimit(instance.getLimit()); 
    this.withMinburst(instance.getMinburst()); 
    this.withPeakrate(instance.getPeakrate()); 
    this.withRate(instance.getRate()); 
  }
  private Integer buffer;
  private String device;
  private String hostname;
  private String ipAddress;
  private Integer limit;
  private Long minburst;
  private Long peakrate;
  private String rate;
  public Integer getBuffer() {
    return this.buffer;
  }
  public A withBuffer(Integer buffer) {
    this.buffer=buffer; return (A) this;
  }
  public Boolean hasBuffer() {
    return this.buffer != null;
  }
  public String getDevice() {
    return this.device;
  }
  public A withDevice(String device) {
    this.device=device; return (A) this;
  }
  public Boolean hasDevice() {
    return this.device != null;
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIpAddress() {
    return this.ipAddress;
  }
  public A withIpAddress(String ipAddress) {
    this.ipAddress=ipAddress; return (A) this;
  }
  public Boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  public Integer getLimit() {
    return this.limit;
  }
  public A withLimit(Integer limit) {
    this.limit=limit; return (A) this;
  }
  public Boolean hasLimit() {
    return this.limit != null;
  }
  public Long getMinburst() {
    return this.minburst;
  }
  public A withMinburst(Long minburst) {
    this.minburst=minburst; return (A) this;
  }
  public Boolean hasMinburst() {
    return this.minburst != null;
  }
  public Long getPeakrate() {
    return this.peakrate;
  }
  public A withPeakrate(Long peakrate) {
    this.peakrate=peakrate; return (A) this;
  }
  public Boolean hasPeakrate() {
    return this.peakrate != null;
  }
  public String getRate() {
    return this.rate;
  }
  public A withRate(String rate) {
    this.rate=rate; return (A) this;
  }
  public Boolean hasRate() {
    return this.rate != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkBandwidthSpecFluentImpl that = (NetworkBandwidthSpecFluentImpl) o;
    if (buffer != null ? !buffer.equals(that.buffer) :that.buffer != null) return false;
    if (device != null ? !device.equals(that.device) :that.device != null) return false;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (ipAddress != null ? !ipAddress.equals(that.ipAddress) :that.ipAddress != null) return false;
    if (limit != null ? !limit.equals(that.limit) :that.limit != null) return false;
    if (minburst != null ? !minburst.equals(that.minburst) :that.minburst != null) return false;
    if (peakrate != null ? !peakrate.equals(that.peakrate) :that.peakrate != null) return false;
    if (rate != null ? !rate.equals(that.rate) :that.rate != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(buffer,  device,  hostname,  ipAddress,  limit,  minburst,  peakrate,  rate,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (buffer != null) { sb.append("buffer:"); sb.append(buffer + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (limit != null) { sb.append("limit:"); sb.append(limit + ","); }
    if (minburst != null) { sb.append("minburst:"); sb.append(minburst + ","); }
    if (peakrate != null) { sb.append("peakrate:"); sb.append(peakrate + ","); }
    if (rate != null) { sb.append("rate:"); sb.append(rate); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkBandwidthSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkBandwidthSpecFluentImpl<A extends NetworkBandwidthSpecFluent<A>> extends BaseFluent<A> implements NetworkBandwidthSpecFluent<A>{
  public NetworkBandwidthSpecFluentImpl() {
  }
  public NetworkBandwidthSpecFluentImpl(NetworkBandwidthSpec instance) {
    if (instance != null) {
      this.withBuffer(instance.getBuffer());
      this.withDevice(instance.getDevice());
      this.withHostname(instance.getHostname());
      this.withIpAddress(instance.getIpAddress());
      this.withLimit(instance.getLimit());
      this.withMinburst(instance.getMinburst());
      this.withPeakrate(instance.getPeakrate());
      this.withRate(instance.getRate());
    }
  }
  private Integer buffer;
  private String device;
  private String hostname;
  private String ipAddress;
  private Integer limit;
  private Long minburst;
  private Long peakrate;
  private String rate;
  public Integer getBuffer() {
    return this.buffer;
  }
  public A withBuffer(Integer buffer) {
    this.buffer=buffer; return (A) this;
  }
  public Boolean hasBuffer() {
    return this.buffer != null;
  }
  public String getDevice() {
    return this.device;
  }
  public A withDevice(String device) {
    this.device=device; return (A) this;
  }
  public Boolean hasDevice() {
    return this.device != null;
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIpAddress() {
    return this.ipAddress;
  }
  public A withIpAddress(String ipAddress) {
    this.ipAddress=ipAddress; return (A) this;
  }
  public Boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  public Integer getLimit() {
    return this.limit;
  }
  public A withLimit(Integer limit) {
    this.limit=limit; return (A) this;
  }
  public Boolean hasLimit() {
    return this.limit != null;
  }
  public Long getMinburst() {
    return this.minburst;
  }
  public A withMinburst(Long minburst) {
    this.minburst=minburst; return (A) this;
  }
  public Boolean hasMinburst() {
    return this.minburst != null;
  }
  public Long getPeakrate() {
    return this.peakrate;
  }
  public A withPeakrate(Long peakrate) {
    this.peakrate=peakrate; return (A) this;
  }
  public Boolean hasPeakrate() {
    return this.peakrate != null;
  }
  public String getRate() {
    return this.rate;
  }
  public A withRate(String rate) {
    this.rate=rate; return (A) this;
  }
  public Boolean hasRate() {
    return this.rate != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkBandwidthSpecFluentImpl that = (NetworkBandwidthSpecFluentImpl) o;
    if (!java.util.Objects.equals(buffer, that.buffer)) return false;

    if (!java.util.Objects.equals(device, that.device)) return false;

    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(ipAddress, that.ipAddress)) return false;

    if (!java.util.Objects.equals(limit, that.limit)) return false;

    if (!java.util.Objects.equals(minburst, that.minburst)) return false;

    if (!java.util.Objects.equals(peakrate, that.peakrate)) return false;

    if (!java.util.Objects.equals(rate, that.rate)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(buffer,  device,  hostname,  ipAddress,  limit,  minburst,  peakrate,  rate,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (buffer != null) { sb.append("buffer:"); sb.append(buffer + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (limit != null) { sb.append("limit:"); sb.append(limit + ","); }
    if (minburst != null) { sb.append("minburst:"); sb.append(minburst + ","); }
    if (peakrate != null) { sb.append("peakrate:"); sb.append(peakrate + ","); }
    if (rate != null) { sb.append("rate:"); sb.append(rate); }
    sb.append("}");
    return sb.toString();
  }
  
}
